<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/include/language/en_us.lang.php,v 1.68 2005/04/26 06:50:39 rank Exp $
 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/
$app_strings = array (
'LBL_BROWSER_TITLE' => 'vtiger CRM 5 - Commercial Open Source CRM',
'LBL_MY_ACCOUNT' => 'My Account',
'LBL_MY_PREFERENCES' => 'My Preferences',
'LBL_ADMIN' => 'Admin',
'LBL_LOGOUT' => 'Sign Out',
'LBL_SEARCH' => 'Search',
'LBL_LAST_VIEWED' => 'Last Viewed',
'LBL_TODAY'=>'Today',
'LBL_ALL'=>'All',
'LBL_SHOW'=>'Show :',
'today'=>"Today's",
'all'=>'All',
'LBL_UPCOMING_EVENTS'=>'Upcoming Activities',
'LBL_PENDING_EVENTS'=>'Pending Activities',
'NTC_WELCOME_MESSAGE' => 'Welcome to vtiger CRM!',
'NTC_DESCRIPTION' => 'Use a valid username and password to login to the vtiger CRM.',
'NTC_WELCOME' => 'Welcome',
'NTC_NO_ITEMS_DISPLAY' => 'none',
'LBL_OR' => 'or',
'LBL_ALT_HOT_KEY' => 'Alt+',
'LBL_SAVE_LABEL' => 'Save',
'LBL_REPLACE_LABEL' => 'Replace',
'LBL_APPLY_BUTTON_LABEL' => 'Apply',
'LBL_SEND_MAIL_BUTTON' => 'Send Mail',
'LBL_SAVE_BUTTON_TITLE' => 'Save [Alt+S]',
'LBL_EDIT_BUTTON_TITLE' => 'Edit [Alt+E]',
'LBL_CONVERTSO_BUTTON_TITLE' => 'Create SalesOrder',
'LBL_CONVERTINVOICE_BUTTON_TITLE' => 'Create Invoice',
'LBL_EDIT_BUTTON' => 'Edit',
'LBL_DUPLICATE_BUTTON_TITLE' => 'Duplicate [Alt+U]',
'LBL_DUPLICATE_BUTTON' => 'Duplicate',
'LBL_TABCUSTOMISE_BUTTON_TITLE' => 'Customise [Alt+C]',
'LBL_FORUM_HIDE_BUTTON_TITLE' => 'Hide Forum [Alt+I]',
'LBL_FORUM_HIDE_BUTTON_KEY' => 'H',
'LBL_FORUM_SHOW_BUTTON_TITLE' => 'Show Forum [Alt+W]',
'LBL_FORUM_SHOW_BUTTON_KEY' => 'W',
'LBL_TABCUSTOMISE_BUTTON' => 'Customise',
'LBL_DELETE_BUTTON_TITLE' => 'Delete [Alt+D]',
'LBL_DELETE_BUTTON' => 'Delete',
'LBL_FIND_BUTTON' => 'Find',
'LBL_CONVERT_BUTTON_TITLE' => 'Convert [Alt+C]',
'LBL_CONVERT_BUTTON_KEY' => 'C',
'LBL_CONVERT_BUTTON_LABEL' => 'Convert Lead',
'LBL_TABCUSTOMISE_BUTTON_KEY' => 'C',
'LBL_TABCUSTOMISE_BUTTON_LABEL' => 'Customize Tab',
'LBL_ROLES_BUTTON_LABEL' => 'Show Roles',
'LBL_LISTROLES_BUTTON_LABEL' => 'List Roles',
'LBL_FORUM_HIDE_BUTTON_LABEL' => 'Hide Forums',
'LBL_FORUM_SHOW_BUTTON_LABEL' => 'Show Forums',
'LBL_NEW_BUTTON_TITLE' => 'New [Alt+N]',
'LBL_CHANGE_BUTTON_TITLE' => 'Change [Alt+G]',
'LBL_CANCEL_BUTTON_TITLE' => 'Cancel [Alt+X]',
'LBL_SEARCH_BUTTON_TITLE' => 'Search [Alt+Q]',
'LBL_CLEAR_BUTTON_TITLE' => 'Clear [Alt+C]',
'LBL_SELECT_BUTTON_TITLE' => 'Select [Alt+T]',
'LBL_CREATE_BUTTON_LABEL' => 'Create',
'LBL_GENERATE' => 'Generate',
'LBL_SAVE_BUTTON_KEY' => 'S',
'LBL_EDIT_BUTTON_KEY' => 'E',
'LBL_CONVERTSO_BUTTON_KEY' => 'S',
'LBL_CONVERTINVOICE_BUTTON_KEY' => 'I',
'LBL_DUPLICATE_BUTTON_KEY' => 'U',
'LBL_DELETE_BUTTON_KEY' => 'D',
'LBL_NEW_BUTTON_KEY' => 'N',
'LBL_CHANGE_BUTTON_KEY' => 'G',
'LBL_CANCEL_BUTTON_KEY' => 'X',
'LBL_SEARCH_BUTTON_KEY' => 'Q',
'LBL_CLEAR_BUTTON_KEY' => 'C',
'LBL_SELECT_BUTTON_KEY' => 'T',
'LBL_SAVE_BUTTON_LABEL' => 'Save',
'LBL_EDIT_BUTTON_LABEL' => 'Edit',
'LBL_CONVERTSO_BUTTON_LABEL' => 'Create SalesOrder',
'LBL_CONVERTINVOICE_BUTTON_LABEL' => 'Create Invoice',
'LBL_DUPLICATE_BUTTON_LABEL' => 'Duplicate',
'LBL_DELETE_BUTTON_LABEL' => 'Delete',
'LBL_NEW_BUTTON_LABEL' => 'New',
'LBL_CHANGE_BUTTON_LABEL' => 'Change',
'LBL_CANCEL_BUTTON_LABEL' => 'Cancel',
'LBL_SEARCH_BUTTON_LABEL' => 'Search',
'LBL_CLEAR_BUTTON_LABEL' => 'Clear',
'LBL_SELECT_BUTTON_LABEL' => 'Select',
'LBL_SELECT_CONTACT_BUTTON_TITLE' => 'Select Contact [Alt+T]',
'LBL_SELECT_CONTACT_BUTTON_KEY' => 'T',
'LBL_SELECT_CONTACT_BUTTON_LABEL' => 'Select Contacts',
'LBL_SELECT_CAMPAIGN_BUTTON_LABEL' => 'Select Campaign',
'LBL_SELECT_USER_BUTTON_TITLE' => 'Select User [Alt+U]',
'LBL_SELECT_USER_BUTTON_KEY' => 'U',
'LBL_SELECT_USER_BUTTON_LABEL' => 'Select User',
'LBL_SETTINGS' => 'Settings',
'LBL_LIST_USERIP' => 'User IP',
'LBL_LIST_SIGNIN' => 'Sign in Time',
'LBL_LIST_SIGNOUT' => 'Sign out Time',
'LBL_LIST_STATUS' => 'Status',
'LBL_LIST_NAME' => 'Name',
'LBL_LIST_USER_NAME' => 'User Name',
'LBL_LIST_EMAIL' => 'Email',
'LBL_LIST_PHONE' => 'Phone',
'LBL_LIST_CONTACT_NAME' => 'Contact Name',
'LBL_LIST_ACCOUNT_NAME' => 'Account Name',
'LBL_USER_LIST' => 'User List',
'LBL_CONTACT_LIST' => 'Contact List',
'LBL_LNK_SETTINGS' => 'Settings',
'LNK_IMPORT_LEADS' => 'Import Leads',
'LBL_LOCATE_MAP' => 'Locate Map',
'LBL_ADDRESS' => 'Address',
'LBL_ADD_TAG' => 'Add Tag',
'LBL_TAG_IT' => 'Tag it',
'LBL_CLOSE' => 'Close',
'LNK_ADVANCED_SEARCH' => 'Advanced Search',
'LNK_BASIC_SEARCH' => 'Basic Search',
'LNK_EDIT' => 'edit',
'LNK_REMOVE' => 'rem',
'LNK_DELETE' => 'del',
'LNK_LIST_START' => 'Start',
'LNK_LIST_NEXT' => 'Next',
'LNK_LIST_PREVIOUS' => 'Previous',
'LNK_LIST_END' => 'End',
'LBL_LIST_OF' => 'of',
'LNK_PRINT' => 'Print',
'LNK_HELP' => 'Help',
'LNK_VTDOCS' => 'vtiger Docs',
'LNK_ABOUT' => 'About',
'LNK_OUTLOOK' => './include/images/outlook_download.gif',
'SINGLE_Accounts' => 'Account',
'SINGLE_Contacts' => 'Contact',
'SINGLE_Campaigns' => 'Campaign',
'SINGLE_HelpDesk' => 'Ticket',
'SINGLE_Leads' => 'Lead',
'SINGLE_Events' => 'Event',
'SINGLE_Calendar' => 'To Do',
'SINGLE_Dashboard' => 'Dashboard',
'SINGLE_Emails' => 'Email',
'SINGLE_Faq' => 'Faq',
'SINGLE_Home' => 'Home',
'SINGLE_Invoice' => 'Invoice',
'SINGLE_Potentials' => 'Potential',
'SINGLE_Products' => 'Product',
'SINGLE_Vendors' => 'Vendor',
'SINGLE_PriceBooks' => 'PriceBook',
'SINGLE_Quotes' => 'Quote',
'SINGLE_PurchaseOrder' => 'PurchaseOrder',
'SINGLE_SalesOrder' => 'SalesOrder',
'SINGLE_Rss' => 'Rss',
'SINGLE_Reports' => 'Report',
'SINGLE_Portal' => 'Portal',
'SINGLE_Webmails' => 'Webmail',
'SINGLE_Users' => 'User',
'NEW' => 'New',
'NTC_REQUIRED' => 'Indicates required field',
'LBL_REQUIRED_SYMBOL' => '*',
'LBL_CURRENCY_SYMBOL' => '$',
'LBL_THOUSANDS_SYMBOL' => 'K',
'NTC_DATE_FORMAT' => '(yyyy-mm-dd)',
'NTC_TIME_FORMAT' => '(24:00)',
'NTC_DATE_TIME_FORMAT' => '(yyyy-mm-dd 24:00)',
'NTC_DELETE_CONFIRMATION' => 'Are you sure you want to delete this record?',
'NTC_ACCOUNT_DELETE_CONFIRMATION' => 'Deleting this account will remove its related Potentials & Quotes. Are you sure you want to delete this account?',
'NTC_VENDOR_DELETE_CONFIRMATION' => 'Deleting this vendor will remove its related Purchase Orders. Are you sure you want to delete this vendor?',
'ERR_DELETE_RECORD' => 'A record number must be specified to delete the contact.',
'ERR_CREATING_TABLE' => 'Error creating table: ',
'ERR_CREATING_FIELDS' => 'Error filling in additional detail fields: ',
'ERR_MISSING_REQUIRED_FIELDS' => 'Missing required fields:',
'ERR_INVALID_EMAIL_ADDRESS' => 'not a valid email address.',
'ERR_INVALID_YAHOO_EMAIL_ADDRESS' => 'not a valid yahoo email address.',
'ERR_INVALID_DATE_FORMAT' => 'The date format must be: yyyy-mm-dd',
'ERR_INVALID_MONTH' => 'Please enter a valid month.',
'ERR_INVALID_DAY' => 'Please enter a valid day.',
'ERR_INVALID_YEAR' => 'Please enter a valid 4 digit year.',
'ERR_INVALID_DATE' => 'Please enter a valid date.',
'ERR_INVALID_HOUR' => 'Please enter a valid hour.',
'ERR_INVALID_TIME' => 'Please enter a valid time.',
'NTC_CLICK_BACK' => 'Please click the browser back button and fix the error.',
'LBL_LIST_ASSIGNED_USER' => 'Assigned To',
'LBL_ASSIGNED_TO' => 'Assigned To',
'LBL_DATE_MODIFIED' => 'Last Modified:',
'LBL_DATE_ENTERED' => 'Created:',
'LBL_CURRENT_USER_FILTER' => 'Only my items:',
'NTC_LOGIN_MESSAGE' => 'Login',
'LBL_NONE' => '--None--',
'LBL_BACK' => 'Back',
'LBL_IMPORT' => 'Import',
'LBL_EXPORT' => 'Export',
'LBL_EXPORT_ALL' => 'Export All',
'LBL_QUICK_CREATE' => 'Quick Create',
'Export' => 'Export',
'Import' => 'Import',
'Merge' => 'Merge',
'ConvertLead' => 'ConvertLead',
'LBL_SHOW_RESULTS' => 'Show Results in',
'LBL_TOTAL_RECORDS_FOUND' => 'Total Records found :',
'LBL_SEARCH_RESULTS_FOR' => ' -- Search results for ',
'LBL_TAG_SEARCH' => ' -- Tag search for ',
'LBL_NO_DATA' => 'No Data Found',
'NTC_MERGE_CONFIRMATION' => 'Are you sure you want to merge this record?',
'LBL_MERGE_BUTTON_TITLE' => 'Merge',
'LBL_MERGE_BUTTON_KEY' => 'Merge',
'LBL_SELECTEMAILTEMPLATE_BUTTON_TITLE' => 'Select Email Template',
'LBL_SELECTEMAILTEMPLATE_BUTTON_KEY' => 'Select Email Template',
'LBL_SELECTEMAILTEMPLATE_BUTTON_LABEL' => 'Select Email Template',
'LBL_MERGE_BUTTON_LABEL' => 'Merge',
'LBL_SENDMAIL_BUTTON_TITLE' => 'SendMail',
'LBL_SENDMAIL_BUTTON_KEY' => 'SendMail',
'LBL_SENDMAIL_BUTTON_LABEL' => 'Send Mail',
'LBL_UPD_DESC' => 'Description',
'LBL_FILENAME' => 'File Name',
'LBL_FILE' => 'File',
'LBL_TYPE' => 'Type',
'LBL_DOWNLOAD' => 'Download Now',
'LBL_OPERATION' => 'Operation',
'LBL_GROUP_ALLOCATION_TITLE' => 'My Group Allocation ',
'LBL_ENTITY_NAME' => 'Entity Name',
'LBL_GROUP_NAME' => 'Group',
'LBL_ENTITY_TYPE' => 'Type',
'LBL_NEW_TICKET' => 'New Ticket',
'LBL_TITLE' => 'Title',
'LBL_PRIORITY' => 'Priority',
'LBL_STATUS' => 'Status',
'LBL_CHANGE_OWNER' => 'Change Owner',
'LBL_CHANGE_STATUS' => 'Change Status',
'LBL_MASS_DELETE' => 'Delete',
'LBL_ADD_ITEM' => 'Add',
'LBL_ADD_NEW' => 'Add',
'LBL_DEDUCT' => 'Deduct',
'LBL_CALENDAR_TITLE' => 'Open Calendar...',
'LBL_CALENDAR_ALT' => 'Open Calendar...',
'LBL_CALCULATOR_TITLE' => 'Open Calculator...',
'LBL_CALCULATOR_ALT' => 'Open Calculator...',
'LBL_CLOCK_TITLE' => 'Show World Clock...',
'LBL_CLOCK_ALT' => 'Show World Clock...',
'LBL_ALL_MENU_TITLE' => 'Open All Menu...',
'LBL_ALL_MENU_ALT' => 'Open All Menu...',
'LBL_CHAT_TITLE' => 'Chat...',
'LBL_CHAT_ALT' => 'Chat...',
'LBL_SEARCH_TITLE' => 'Search in ',
'LBL_SEARCH_ALT' => 'Search in ',
'LBL_SEARCH_STRING' => 'Search...',
'LBL_SEARCH_FOR' => 'Search for',
'LBL_SEARCH_NOW_BUTTON' => 'Search Now',
'LBL_GO_TO' => 'Go to',
'LBL_FEWER_BUTTON' => 'Fewer',
'LBL_IN' => 'In',
'LBL_ADV_SEARCH_MSG_ANY' => 'Match Any of the Following',
'LBL_ADV_SEARCH_MSG_ALL' => 'Match All of the Following',
'COMBO_ALL' => 'All',
'LBL_OPEN_ACTIVITIES' => 'Open Activities',
'LBL_HISTORY' => 'History',
'LBL_ACTIVITY_HISTORY' => 'Activity History',
'LBL_ATTACHMENTS' => 'File Name',
'LBL_ATTACHMENT' => 'Attachment',
'LBL_TIME' => 'Time',
'LBL_ACTION' => 'Action',
'LBL_SUBJECT' => 'Subject',
'LBL_RELATED_TO' => 'Related To',
'LBL_MULTIPLE' => 'Multiple',
'LBL_DUE_DATE' => 'Due Date',
'LBL_LAST_MODIFIED' => 'Last Modified',
'LBL_CREATED' => 'Created',
'LBL_DESCRIPTION' => 'Description',
'LBL_NEW_TASK' => 'New Task',
'LBL_NEW_EVENT' => 'New Event',
'LBL_ATTACHMENT_AND_NOTES' => 'Attachments & Notes',
'LBL_POTENTIAL_NAME' => 'Potential Name',
'LBL_CONTACT_NAME' => 'Contact Name',
'LBL_DEPARTMENT' => 'Department',
'LBL_ROLE' => 'Role',
'LBL_EMAIL' => 'Email',
'LBL_PHONE' => 'Phone',
'LBL_PRODUCT' => 'Product',
'LBL_AMOUNT' => 'Amount',
'LBL_CLOSE_DATE' => 'Close Date',
'LBL_NEW_ATTACHMENT' => 'New Attachment',
'LBL_PRODUCT_TITLE' => 'Products',
'LBL_NEW_PRODUCT' => 'New Product',
'LBL_PRODUCT_NAME' => 'Product Name',
'LBL_QUANTITY' => 'Quantity',
'LBL_SALES_PRICE' => 'Sale Price',
'LBL_PURCHASE_DATE' => 'Purchase Date',
'LBL_TICKET_ID' => 'Ticket Id',
'LBL_TICKETS' => 'Tickets',
'LBL_POTENTIAL_TITLE' => 'Potentials',
'LBL_NEW_POTENTIAL' => 'New Potential',
'LBL_LEAD_NAME' => 'Lead Name',
'LBL_ACCOUNT_NAME' => 'Account Name',
'LBL_ACCOUNT_TYPE' => 'Account Type',
'LBL_USER_TITLE' => 'Users',
'LBL_CONTACT_TITLE' => 'Contacts',
'LBL_SHOWING' => 'Showing',
'LBL_SELECT_PRODUCT_BUTTON_LABEL' => 'Select Products',
'LBL_VIEW' => 'Filters :',
'LBL_GROUP_VIEW' => 'Group',
'LBL_SALES_STAGE' => 'Sales Stage',
'LBL_PROBABILITY' => 'Probability',
'LBL_BULK_MAILS' => 'Bulk Mails',
'LBL_WORLD_CLOCK' => 'World Clock',
'LBL_CALCULATOR' => 'Calculator',
'LBL_CLOSE_WON' => 'Closed Won',
'LBL_CLOSE_LOST' => 'Closed Lost',
'LBL_USER' => 'User',
'LBL_TEAM' => 'Team',
'LBL_GROUP' => 'Group',
'LBL_NONE_NO_LINE' => 'none',
'LBL_SELECT_GROUP' => 'Select a group',
'LBL_HOUR_AND_MINUTE' => '(hours/minutes)',
'YEAR_MONTH_DATE' => '24:00',
'COMBO_LEADS' => 'Leads',
'COMBO_ACCOUNTS' => 'Accounts',
'COMBO_CONTACTS' => 'Contacts',
'COMBO_POTENTIALS' => 'Potentials',
'COMBO_PRODUCTS' => 'Products',
'COMBO_HELPDESK' => 'Trouble Tickets',
'COMBO_USERS' => 'Users',
'COMBO_CAMPAIGNS' => 'Campaigns',
'LBL_SELECT' => 'Select',
'LBL_EDIT' => 'Edit',
'LBL_DELETE' => 'Delete',
'Name' => 'Name',
'Company' => 'Company',
'Phone' => 'Phone',
'Website' => 'Website',
'Email' => 'Email',
'Assigned To' => 'Assigned To',
'Account Name' => 'Account Name',
'City' => 'City',
'Title' => 'Title',
'Potential' => 'Potential',
'Sales Stage' => 'Sales Stage',
'Amount' => 'Amount',
'Expected Close' => 'Expected Close',
'Subject' => 'Subject',
'Contact Name' => 'Contact Name',
'Related to' => 'Related To',
'File' => 'File',
'Last Modified' => 'Last Modified',
'Close' => 'Close',
'Type' => 'Type',
'Start Date/Due Date' => 'Start Date/Due Date',
'Date Sent' => 'Date Sent',
'Ticket ID' => 'Ticket ID',
'Status' => 'Status',
'Priority' => 'Priority',
'Product Name' => 'Product Name',
'Commission Rate' => 'Commission Rate',
'Quantity In Stock' => 'Quantity In Stock',
'Qty/Unit' => 'Qty/Unit',
'Unit Price' => 'Unit Price',
'Question' => 'Question',
'Category' => 'Category',
'Price Book Name' => 'Price Book Name',
'LBL_EVENT_ENDDATE' => 'End Date & Time',
'LBL_CUSTOM_INFORMATION' => 'Custom Information',
'LBL_NONE_SCHEDULED' => 'None Scheduled',
'Leads' => 'Leads',
'Accounts' => 'Accounts',
'Accounts & Contacts' => 'Accounts & Contacts',
'Contacts' => 'Contacts',
'Potentials' => 'Potentials',
'Products' => 'Products',
'Emails' => 'Email',
'HelpDesk' => 'Trouble Tickets',
'Activities' => 'Activities',
'Events' => 'Events',
'Tasks' => 'Tasks',
'Todo' => 'To Do',
'Call' => 'Call',
'Meeting' => 'Meeting',
'PriceBook' => 'PriceBook',
'Calendar' => 'Calendar',
'Home' => 'Home',
'Campaigns' => 'Campaigns',
'PriceBooks' => 'Price Books',
'Faq' => 'FAQ',
'Dashboards' => 'Dashboard',
'Reports' => 'Reports',
'Vendors' => 'Vendors',
'Rss' => 'RSS',
'Portal' => 'Our Sites',
'Webmails' => 'Webmail',
'Activity History' => 'Activity History',
'Ticket History' => 'Ticket History',
'Purchase Order' => 'Purchase Order',
'Sales Stage History' => 'Sales Stage History',
'Users' => 'Users',
'Admin' => 'Admin',
'PurchaseOrder Status History' => 'PurchaseOrder Status History',
'SalesOrder Status History' => 'SalesOrder Status History',
'Quote Stage History' => 'Quote Stage History',
'Invoice Status History' => 'Invoice Status History',
'LBL_TROUBLE_TICKET' => 'Trouble Ticket',
'My Home Page' => 'My Home Page',
'Marketing' => 'Marketing',
'Sales' => 'Sales',
'Support' => 'Support',
'Analytics' => 'Analytics',
'Inventory' => 'Inventory',
'Tools' => 'Tools',
'Settings' => 'Settings',
'LBL_INFORMATION' => 'Information',
'LBL_MORE' => 'More',
'LBL_BASIC' => 'Basic',
'LBL_CREATING' => 'Creating',
'LBL_DUPLICATING' => 'Duplicating',
'LBL_EDITING' => 'Editing',
'LBL_NEW' => 'New',
'Lead' => 'Lead',
'Account' => 'Account',
'Contact' => 'Contact',
'Opportunity' => 'Potential',
'Product' => 'Product',
'Activity' => 'Activity',
'Event' => 'Event',
'Task' => 'Task',
'Quote' => 'Quote',
'Ticket' => 'Ticket',
'Campaign' => 'Campaign',
'Dashboard' => 'Dashboards',
'Report' => 'Report',
'Vendor' => 'Vendor',
'Webmail' => 'Webmail',
'LBL_NONE_INCLUDED' => 'None Included',
'LBL_ADD_TO' => 'Add to',
'LBL_SELECT_TEMPLATE_TO_MAIL_MERGE' => 'Select template to Mail Merge:',
'LBL_TITLE_OR_DESCRIPTION' => 'Title / Description',
'LBL_RSS_FEEDS' => 'RSS Feeds',
'LBL_ADD_RSS_FEEDS' => 'Add New RSS Feed',
'LNK_NEW_FAQ' => 'New FAQ',
'Vendor Name' => 'Vendor Name',
'LNK_WEARE' => 'About Us',
'LBL_ABOUTUS_TITLE' => 'vtiger CRM - About Us',
'LBL_DISCUSS' => 'Discuss with other users',
'Quote Stage' => 'Quote Stage',
'Potential Name' => 'Potential Name',
'Total' => 'Total Amount',
'First Name' => 'First Name',
'Last Name' => 'Last Name',
'User Name' => 'User Name',
'LBL_PORDER_BUTTON_TITLE' => 'New Purchase Order [Alt+O]',
'LBL_PORDER_BUTTON' => 'New Purchase Order',
'LBL_PORDER_BUTTON_KEY' => 'O',
'Tracking Number' => 'Tracking Number',
'Order No' => 'Order No',
'Quote Name' => 'Quote Name',
'Invoice No' => 'Invoice No',
'Quote No' => 'Quote No',
'Sales Order' => 'Sales Order',
'COMBO_QUOTES' => 'Quotes',
'End Date' => 'End Date',
'End Date & Time' => 'End Date & Time',
'Start Date' => 'Start Date',
'Start Date & Time' => 'Start Date & Time',
'Recurring Type' => 'Recurring Type',
'SalesOrders' => 'Sales Order',
'LBL_QUOTE_NAME' => 'Quote Name',
'LBL_NEW_QUOTE_BUTTON_TITLE' => 'New Quote [Alt+Q]',
'LBL_NEW_QUOTE_BUTTON_KEY' => 'Q',
'LBL_NEW_QUOTE_BUTTON' => 'New Quote',
'COMBO_PORDER' => 'Purchase Order',
'COMBO_SORDER' => 'Sales Order',
'LBL_PORDER_NAME' => 'Purchase Order',
'LBL_SORDER_NAME' => 'Sales Order',
'COMBO_INVOICES' => 'Invoice',
'LBL_INVOICE_NAME' => 'Invoice',
'LBL_QUOTES_NAME' => 'Quote',
'LBL_HELPDESK_NAME' => 'Trouble Ticket',
'LBL_CAMPAIGN_NAME' => 'Campaign Name',
'LBL_NEW_INVOICE_BUTTON_TITLE' => 'New Invoice [Alt+I]',
'LBL_NEW_INVOICE_BUTTON_KEY' => 'I',
'LBL_NEW_INVOICE_BUTTON' => 'New Invoice',
'LBL_NEW_SORDER_BUTTON_TITLE' => 'New Sales Order [Alt+E]',
'LBL_NEW_SORDER_BUTTON_KEY' => 'E',
'LBL_NEW_SORDER_BUTTON' => 'New Sales Order',
'LBL_PRODUCT_DETAILS' => 'Product Details',
'LBL_QTY_IN_STOCK' => 'Qty In Stock',
'LBL_QTY' => 'Qty',
'LBL_UNIT_PRICE' => 'Unit Price',
'LBL_LIST_PRICE' => 'List Price',
'LBL_TOTAL' => 'Total',
'LBL_ADD_PRODUCT' => 'Add Product',
'LBL_SUB_TOTAL' => 'Sub Total',
'LBL_TAX' => 'Tax',
'LBL_ADJUSTMENT' => 'Adjustment',
'LBL_GRAND_TOTAL' => 'Grand Total',
'LBL_QUOTE_ID' => 'Quote Id',
'LBL_SALES_ORDER_ID' => 'Sales Order Id',
'LBL_PURCHASE_ORDER_ID' => 'Purchase Order Id',
'LBL_EXPORT_TO_PDF' => 'Export To PDF',
'LBL_HOME_KEY_METRICS' => 'Key Metrics',
'LBL_HOME_METRICS' => 'Metrics',
'LBL_HOME_COUNT' => 'Count',
'LBL_JSCALENDAR_LANG' => 'en',
'LNK_CV_EDIT' => 'Edit',
'LNK_CV_DELETE' => 'Delete',
'LNK_CV_CREATEVIEW' => 'New',
'LBL_UPD_FIELD_ORD' => 'Update Field Order',
'LBL_SEND_CUSTOM_MAIL_BUTTON' => 'Send Custom Mail',
'LBL_UPDATED_TODAY' => 'Updated today',
'LBL_UPDATED' => 'Updated',
'LBL_DAY_AGO' => 'day ago',
'LBL_DAYS_AGO' => 'days ago',
'Jan' => 'Jan',
'Feb' => 'Feb',
'Mar' => 'Mar',
'Apr' => 'Apr',
'May' => 'May',
'Jun' => 'Jun',
'Jul' => 'Jul',
'Aug' => 'Aug',
'Sep' => 'Sep',
'Oct' => 'Oct',
'Nov' => 'Nov',
'Dec' => 'Dec',
'Campaign Name' => 'Campaign Name',
'Campaign Type' => 'Campaign Type',
'Campaign Status' => 'Campaign Status',
'Expected Revenue' => 'Expected Revenue',
'Expected Close Date' => 'Expected Close Date',
'LBL_ACTIONS' => 'Actions',
'LBL_SEND' => 'Send',
'LBL_VAT' => 'VAT',
'LBL_SALES' => 'Sales',
'LBL_SERVICE' => 'Service',
'LBL_TAX_DETAILS' => 'Tax Details',
'LBL_TAX_CALCULATION' => 'Tax Calculation',
'LBL_TAX_NAME' => 'Tax Name',
'LBL_TAX_VALUE' => 'Tax Value',
'COVERED_PERCENTAGE' => '(%)',
'LBL_TAG_CLOUD' => 'Tag Cloud',
'LBL_FOR' => 'for',
'LBL_PO_STATUS' => 'PurchaseOrder Status',
'LBL_SO_STATUS' => 'SalesOrder Status',
'LBL_INVOICE_STATUS' => 'Invoice Status',
'LBL_MODULE' => 'Module',
'Active' => 'Active',
'Inactive' => 'Inactive',
'Today' => 'Today',
'Last 2 Days' => 'Last 2 Days',
'Last Week' => 'Last Week',
'This Week' => 'This Week',
'This Month' => 'This Month',
'This Year' => 'This Year',
'LBL_PLEASE_CLICK' => 'Please Click',
'LBL_TO_CONFIGURE' => 'to Configure',
'LBL_HERE' => 'here',
'LBL_RECORDS' => 'Records',
'LBL_SCROLL' => '[Scroll to Top]',
'LBL_EXPAND_COLLAPSE' => 'Expand/Collapse',
'LBL_RCPY_ADDRESS' => 'Copy Shipping address',
'LBL_LCPY_ADDRESS' => 'Copy Billing address',
'LBL_RECORD_ID' => 'Record ID',
'LBL_ACTION_DATE' => 'Action Date',
'LBL_HOMEPAGE_DASHBOARD' => 'Home Page Dashboard',
'LBL_NO' => 'No',
'LBL_FOUND' => 'Found',
'LBL_YOU_CAN_CREATE' => 'You can Create',
'LBL_NOW' => 'now',
'LBL_CLICK_THE_LINK' => 'Click the link below',
'LBL_CREATE' => 'Create',
'LBL_A' => 'a',
'LBL_AN' => 'an',
'LBL_YOU_ARE_NOT_ALLOWED_TO_CREATE' => 'You are not allowed to create',
'LBL_TRANSFER_OWNERSHIP' => 'Transfer Ownership to',
'LBL_SELECT_STATUS' => 'Select New Status',
'LBL_UPDATE_OWNER' => 'Update Owner',
'LBL_UPDATE_STATUS' => 'Update Status',
'LBL_NET_PRICE' => 'Net Price',
'LBL_TOOLS' => 'Tools',
'LBL_DISCOUNT' => 'Discount',
'LBL_TOTAL_AFTER_DISCOUNT' => 'Total After Discount',
'LBL_NET_TOTAL' => 'Net Total',
'LBL_SHIPPING_AND_HANDLING_CHARGES' => 'Shipping & Handling Charges',
'LBL_TAX_FOR_SHIPPING_AND_HANDLING' => 'Taxes For Shipping and Handling',
'LBL_FINISH' => 'Finish',
'LBL_IMAGE_DELETED' => 'Image Deleted',
'LBL_TAX_MODE' => 'Tax Mode',
'LBL_CLEAR_COMMENT' => 'Clear Comment',
'LBL_ZERO_DISCOUNT' => 'Zero Discount',
'LBL_OF_PRICE' => 'of Price',
'LBL_DIRECT_PRICE_REDUCTION' => 'Direct Price Reduction',
'LBL_INDIVIDUAL' => 'individual',
'LBL_CPY_MAILING_ADDRESS' => 'Copy Mailing Address',
'LBL_CPY_OTHER_ADDRESS' => 'Copy Other Address',
'LBL_PERMISSION' => 'You are not permitted to execute this Operation',
'VTIGER' => 'vtiger',
'LBL_DIRECT_AMOUNT_DISCOUNT' => 'Direct Amount Discount',
'LBL_NO_DISCOUNT_FOR_THIS_PRODUCT' => 'No Discount for this Product',
'LBL_NO_DISCOUNT_FOR_THIS_LINE_ITEM'=> 'No Discount for this line item',
'LBL_TOTAL_TAX_AMOUNT' => 'Total Tax Amount',
'LBL_FINAL_DISCOUNT_AMOUNT' => 'Final Discount Amount',
'LBL_SHIPPING_AND_HANDLING_CHARGE' => 'Shipping & Handling Charge',
'LBL_GO_BACK' => 'Go Back',
'LBL_RECORD_DELETE' => 'The record you are trying to view has been deleted.',
'Part Number' => 'Part Number',
'Salutation' => 'Salutation ',
'Rating' => 'Rating',
'industry' => 'Industry',
'Severity' => 'Severity',
'Product Category' => 'Product Category',
'GL Account' => 'GL Account',
'Usage Unit' => 'Usage Unit',
'Carrier' => 'Carrier',
'Expected Response' => 'Expected Response',
'LBL_ADDRESS_INF' => 'Address Information',
'yes' => 'yes',
'no' => 'no',
'LBL_RENAMEPROFILE_BUTTON_LABEL'=>'Rename',
'LBL_RENAME_PROFILE'=>'Rename Profile',
'LBL_PROFILE_NAME'=>'Profile Name',
'LBL_START_DATE'=>'Start Date',
'LBL_START_DATE_TIME'=>'Start Date & Time',
'LBL_END_DATE'=>'End Date',
'LBL_END_DATE_TIME'=>'End Date & Time',
'LBL_CREATE_MERGE_TEMPLATE'=>'Create Mail Merge templates ',
'LBL_IMG_FORMATS'=>'(Only jpg, gif, bmp and png images)',

//Added for Taxmode in detail view of Product Details.
'group'=>'Group',
'individual'=>'individual',

//Added for values of picklist in Advanced Search filter
//Modified for 5.0.3 GA release
'contains'=>'contains',
'does_not_contains'=>'does not contains',
'is'=>'is',
'is_not'=>'is not',
'begins_with'=>'begins with',
'ends_with'=>'ends with',
'greater_than'=>'greater than',
'less_than'=>'less than',
'greater_or_equal'=>'greater or equal',
'less_or_equal'=>'less or equal',

//For Product Details
'LABEL_SET_DISCOUNT_FOR_COLON'=>'Set Discount for :',
'LABEL_SET_TAX_FOR'=>'Set Tax for',
'LABEL_SET_DISCOUNT_FOR'=>'Set Discount for',
'LABEL_SET_GROUP_TAX_FOR_COLON'=>'Set Group Tax for :',
'LABEL_SET_DISCOUNT_FOR_X_COLON'=>'Set Discount for x :',
'LABEL_SET_TAX_FOR_X'=>'Set Tax for x',
'LABEL_SET_SH_TAX_FOR_COLON'=>'Set S&H Tax for :',

'NO_DATA_AVAILABLE_WITH_SPECIFIED_PERIOD'=>'No data available with the specified time period',

//Added for 5.0.3
'Files_Maximum_6'=>'Files Maximum 6',
'To'=>'To:',

'Date & Time' => 'Date & Time',
'Reminder' => '[Reminder:',
'Visit_Link' => 'Kindly visit the link for more details on the activity',
'Click here' => 'Click here',
'Subject' => 'Subject',
'Support_starting' => 'Support starting',
'Congratulations' => 'Congratulations! Your support starts from today',
'Hello_Support' => 'Hello! Support Starts for',
'Support_Ending_Subject' => 'Reg: Support Ending',
'Support_Ending_Content' => 'Dear Admin,<br><br> This is to bring to your notice that Support Date for the product <b>',
'kindly_renew' => '</b> ends shortly. Kindly renew your support please.<br><br>Regards,<br>HelpDesk Team<br>',
'Dear_Admin' => 'Dear Admin,<br> This is to bring to your notice that there are too many tickets pending. Kindly take the necessary action required for addressing the same<br><br> Thanks and Regards,<br> HelpDesk Team<br>',
'Pending_Tickets' => 'Too many pending tickets',
'Pending_Ticket_notification' => 'Pending Ticket notification',
'Kind_Attention' => 'Dear Admin,<br> This is to bring to your kind attention that ticket number ',
'Thank_You_HelpDesk' => ' is yet to be closed<br> Thank You,<br> HelpDesk Team<br>',
'Big_Deal_Closed_Successfully' => 'Big Deal Closed Successfully',
'Dear_Team' => 'Dear Team,<br>',
'Potential_Name' => 'Potential Name:',
'Potential_Id' => 'Potential Id:',
'Dear_Team_Time_to_Party' => '<br>Congratulations!Time to Party! <br>We closed a deal worth more than 10000!!!!<br> Time to hit the dance floor!<br>',
'Task_Not_completed' => 'Task Not completed',
'Too_many_pending_tickets' => 'Too many pending tickets',
'Dear_Admin_too_ many_tickets_pending' => 'Dear Admin,<br> This is to bring to your notice that there are too many tickets pending. Kindly take the necessary action required for addressing the same<br><br> Thanks and Regards,<br> HelpDesk Team<br>',

//Added for java script alerts
'DELETE_CONFIRMATION' => 'Are you sure you want to delete the selected ',
'SELECT_ATLEAST_ONE' => 'Please select at least one entity',
'DELETING_ACCOUNT' => 'Deleting this account(s) will remove its related Potentials,Quotes,Sales Orders & Invoice. Are you sure you want to delete the selected ',
'DELETING_VENDOR' => 'Deleting this vendor(s) will remove its related Purchase Orders. Are you sure you want to delete the selected ',
'PLEASE_SELECT_MAILID' => 'Please Select a mailid',
'OVERWRITE_EXISTING_ACCOUNT1' => 'Do you want to Overwrite the existing address with this selected account(',
'OVERWRITE_EXISTING_ACCOUNT2' => ') address details?',
'MISSING_FIELDS' => 'Missing required fields:',
'NOT_ALLOWED_TO_EDIT' => 'you are not allowed to edit this field',
'COLUMNS_CANNOT_BE_EMPTY' => 'Selected Columns cannot be empty',
'CANNOT_BE_EMPTY' => ' cannot be empty',
'CANNOT_BE_NONE' => ' cannot be none',
'SERVERNAME_CANNOT_BE_EMPTY' => 'Server Name cannot be empty',
'ENTER_VALID' => 'Please enter a valid ',
'SHOULDBE_LESS' => ' should be less than ',
'SHOULDBE_LESS_EQUAL' => ' should be less than or equal to ',
'SHOULDBE_EQUAL' => ' should be equal to ',
'SHOULDBE_GREATER' => ' should be greater than ',
'SHOULDBE_GREATER_EQUAL' => ' should be greater than or equal to ',
'INVALID' => 'Invalid ',
'EXCEEDS_MAX' => ' exceeds the maximum limit ',
'OUT_OF_RANGE' => ' is out of range',
'SHOULDNOTBE_EQUAL' => ' should not be equal to ',
'PORTAL_PROVIDE_EMAILID' => 'Portal user should provide email Id for portal login',
'ADD_CONFIRMATION' => 'Are you sure you want to add the selected ',
'ACCOUNTNAME_CANNOT_EMPTY' => 'AccountName Cannot be Empty',
'CANT_SELECT_CONTACTS' => "You can\'t select related contacts from Lead",
'LBL_THIS' => 'This ',
'DOESNOT_HAVE_MAILIDS' => " doesn\'t have any mail ids",
'DOESNOT_HAVE_AN_MAILID' => '" '."doesn\'t have an Email Id",
'ARE_YOU_SURE' => 'Are you sure?',
'MISSING_REPORT_NAME' => 'Missing Report Name',
'REPORT_NAME_EXISTS' => 'Report name already exists, try again...',
'WANT_TO_CHANGE_CONTACT_ADDR' => 'Do you want to change the addresses of the Contacts related to this Account?',
'SURE_TO_DELETE' => 'Are you sure you want to delete ?',
'RECORDS' => ' records ?',
'NO_PRODUCT_SELECTED' => 'No product is selected. Select at least one Product',
'VALID_FINAL_PERCENT' => 'Enter valid Final Discount Percentage',
'VALID_FINAL_AMOUNT' => 'Enter valid Final Discount Amount',
'VALID_SHIPPING_CHARGE' => 'Enter a valid Shipping & Handling charge',
'VALID_ADJUSTMENT' => 'Enter a valid Adjustment',
'SELECTED_MORE_THAN_ONCE' => 'You have selected  the following product(s) more than once.',
'WANT_TO_CONTINUE' => 'Do you want to Continue?',
'ENTER_VALID_TAX' => 'Please enter Valid TAX value',
'VALID_TAX_NAME' => 'Enter valid Tax Name',
'CORRECT_TAX_VALUE' => 'Enter Correct Tax Value',
'ENTER_POSITIVE_VALUE' => 'Please enter positive value',
'LABEL_SHOULDNOT_EMPTY' => 'The tax label name should not be empty',
'NOT_VALID_ENTRY' => 'is not a valid entry. Please enter correct value',
'VALID_DISCOUNT_PERCENT' => 'Enter a valid Discount percentage',
'VALID_DISCOUNT_AMOUNT' => 'Enter a valid Discount Amount',
'SELECT_TEMPLATE_TO_MERGE' => 'Please select a template to merge',
'MISSING_REQUIRED_FIELDS' => 'Missing required fields: ',
'READONLY' => "it\'s readonly",
'SELECT_ATLEAST_ONE_USER' => 'Please select at least one user',
'DISABLE_SHARING_CONFIRMATION' => 'Are you sure you want to disable sharing for selected ',
'USERS' => ' user(s) ?',
'ENDTIME_GREATER_THAN_STARTTIME' => 'End Time should be greater than Start Time ',
'FOLLOWUPTIME_GREATER_THAN_STARTTIME' => 'Followup Time should be greater than End Time ',
'MISSING_EVENT_NAME' => 'Missing Event Name',
'EVENT_TYPE_NOT_SELECTED' => 'Event Type is not selected',
'OPPORTUNITYNAME_CANNOT_BE_EMPTY' => 'Potential Name field cannot be empty',
'CLOSEDATE_CANNOT_BE_EMPTY' => 'Close Date field cannot be empty',
'SITEURL_CANNOT_BE_EMPTY' => 'Site Url cannot be empty',
'SITENAME_CANNOT_BE_EMPTY' => 'Site Name cannot be empty',
'LISTPRICE_CANNOT_BE_EMPTY' => 'List Price cannot be empty',
'INVALID_LIST_PRICE' => 'Invalid List Price',
'PROBLEM_ACCESSSING_URL' => 'Problem accessing url: ',
'CODE' => ' Code: ',
'WISH_TO_QUALIFY_MAIL_AS_CONTACT' => 'Are you sure you wish to Qualify this Mail as Contact?',
'SELECT_ATLEAST_ONEMSG_TO_DEL' => 'Please select at least one message to delete',
'ERROR' => 'Error',
'FIELD_TYPE_NOT_SELECTED' => 'Field Type is not selected',
'SPECIAL_CHARACTERS_NOT_ALLOWED' => 'Special characters are not allowed in Label field',
'DUPLICATE_MAPPING_ACCOUNTS' => 'Duplicate mapping for accounts!!',
'DUPLICATE_MAPPING_CONTACTS' => 'Duplicate mapping for Contacts!!',
'DUPLICATE_MAPPING_POTENTIAL' => 'Duplicate mapping for Potential!!',
'ERROR_WHILE_EDITING' => 'Error while Editing',
'PLEASE_ENTER_TAG' => 'Please enter a tag',
'PLEASE_SELECT_LINE_ITEM' => 'Please select a Line Item',
'DUPLICATE_ENTRIES_FOUND' => "Duplicate entries found for the value \'",
'ROLE_SHOULDHAVE_INFO' => 'Role should have at least one profile',
'ENTER_VALID_CONVERSION_RATE' => 'Enter valid Conversion Rate',
'GROUPNAME_CANNNOT_BE_NONE' => 'Group Name cannot be none',
'GROUP_SHOULDHAVE_ONEMEMBER_INFO' => 'Group should have at least one member. Select a member to the group',
'MAP_DELETED_INFO' => 'This map has been deleted. You cannot use this map again',
'MUSTHAVE_ONE_REQUIREDFIELD' => 'Must have one Required field to be selected\n',
'COLUMNS_CANNOT_BE_DUPLICATED' => 'Columns cannot be duplicated',
'SPECIFY_ROLE_INFO' => 'Specfiy the Role to Transfer Existing Roles Users',
'FOLDERNAME_CANNOT_BE_EMPTY' => 'The Folder name cannot be empty',
'FOLDER_NAME_ALREADY_EXISTS' => 'Folder name already exists, try again...',
'SELECT_ATLEAST_ONE_REPORT' => 'Please select at least one Report',
'DELETE_FOLDER_CONFIRMATION' => "Are you sure you want to delete the folder  \'",
'DELETE_REPORT_CONFIRMATION' => 'Are you sure you want to delete this report ?',
'MOVE_REPORT_CONFIRMATION' => 'Are you sure you want to move this report to ',
'FOLDER' => ' folder ?',
'ACCOUNT_ACCESS_INFO' => 'Potentials, HelpDesk, Quotes, SalesOrder & Invoice Access must be set to Private when the Account Access is set to Private',
'PROFILENAME_CANNOT_BE_EMPTY' => 'Profile Name Cannot be empty',
'PROFILE_DETAILS_UPDATED' => 'Profile Details are updated',
'CURRENCY_CHANGE_INFO' => 'Currency Changes has been made Successfully',
'CURRENCY_CONVERSION_INFO' => 'Are you using Dollar $ as Currency? \n Click OK to remain as $, Cancel to change the currency conversion rate.',
'THE_EMAILID' => "The email id \'",
'EMAIL_FIELD_INVALID' => "\' in the email field is invalid",
'SELECT_VALID_IMAGE' => 'Please Select a Valid Image',
'EMAIL_FILED_IS' => "\' in the email field is ",
'OTHER_EMAIL_FILED_IS' => "\' in other email field is ",
'YAHOO_EMAIL_FILED_IS' => "\' in yahoo email field is ",
'INVALID_ADD_IN_EMAILFIELD' => '\" not a valid email address in Email field',
'INVALID_ADD_IN_OTHER_EMAILFIELD' => '\" not a valid email address in Other Email field',
'ENTER_VALID_4DIGIT_YEAR' => 'Please enter a valid 4 digit year between ',
'AND' => '  and ',
'DATABASE_CHANGE_CONFIRMATION' => 'Are you sure to apply the Database Changes from ',
'TO' => ' to ',
'DELETE_RSSFEED_CONFIRMATION' => 'Are you sure to delete the rss feed?',
'NOT_PERMITTED_TO_EXPORT' => 'you are not permitted to export!',

//Added for 5.0.3
'MSG_DEAR'=>'Dear',
'MSG_REGARDING'=>'Regarding',
'MSG_UPDATION'=>'updation -',
'MSG_THE'=>'The',
'MSG_HAS_BEEN_UPDATED'=>'has been updated',
'MSG_ASSIGNMENT'=>'assignment -',
'MSG_HAS_BEEN_ASSIGNED_TO_YOU'=>'has been assigned to you',
'MSG_DETAILS_ARE'=>'details are',
'MSG_ID'=>'Id :',
'MSG_THANK_YOU'=>'Thank You',
'MSG_HAS_BEEN_CREATED_FOR'=>'has been created for',
'MSG_THANKS'=>'Thanks,',
'MSG_VTIGERTEAM'=>' vTiger Team',
'MSG_IS_NOT_UPLOADED'=>'is not uploaded. Allowed file types - jpeg, png, jpg, pjpeg, x-png or gif',
'MSG_IMAGE_ERROR'=>'Image not found',

'Information'=>'Information',
'Address'=>'Address',
'Custom Information'=>'Custom Information',
'Portal Information'=>'- Portal Information',
'Description'=>'Description',
'Expectations'=>'Expectations',
'Pricing Information'=>'Pricing Information',
'Stock Information'=>'Stock Information',
'Solution'=>'Solution',
'Terms and Conditions'=>'Terms and Conditions',
'LBL_SEARCHING'=>'Searching... please wait',
'LBL_SKYPE'=>'Skype',
'LBL_FIND'=>'Find',
'LBL_CLEAR'=>'Clear',
// Added for display the label of Invoice no
'invoice no'=>'invoice no',
//Added for title to the button Select Lead
'LBL_SELECT_LEAD_BUTTON_LABEL' => 'Select Leads',
//Added for the link Read License in footer
'LNK_READ_LICENSE'=>'Read License',
'ACTIVITIES' => 'Activities',
'MAP_NAME_EXISTS'=>'This map name already exists. \n Do you want to overwrite it?',
'FOLDER_NAME_ALLOW_20CHARS'=> 'Folder name allowed 20 characters only',
'SPECIAL_CHARS_NOT_ALLOWED' => 'Special characters not allowed. try again...',
//Added for title for SignIn Image.
'LBL_SIGN_IN'=>'Sign in',

//Added for title of Root Image
'LBL_ROOT'=>'Root',
'LBL_FIRST'=>'First',
'LBL_LAST'=>'Last',

'LBL_CONTACT_LAST_NAME'=>'Contact - Last Name',
'LBL_CONTACT_FIRST_NAME'=>'Contact - First Name',
'Office Phone'=>'Office Phone',
'Sender'=>'Sender',
'Website'=>'Website',
'Activity Type'=>'Activity Type',
'Due Date'=>'Due Date',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'FAQ Id'=>'FAQ Id',
'Lead Status'=>'Lead Status',
'Lead Source'=>'Lead Source',
'Quote No'=>'Quote No',
'Yahoo Id'=>'Yahoo Id',

// Added/Updated for vtiger CRM 5.0.4
'LBL_CHARSET' => 'UTF-8',
'Lost Lead' => 'Lost Lead',
'LBL_SEND_EMAIL_PDF' => 'Send Email With PDF',
//Added for incoming mail server settings form js validation
'ERR_INVALID_PAGE_COUNT' => "Invalid Page count",
//'Product Code' => 'Part Number',
'Quotes' => 'Quotes',
'PurchaseOrder' => 'Purchase Order',
'SalesOrder' => 'Sales Order',
'Invoice' => 'Invoice',
//added for #3012
'LBL_CREATING_NEW_Contacts' => 'Creating New Contact',
'LBL_CREATING_NEW_Campaigns' => 'Creating New Campaign',
'LBL_CREATING_NEW_Leads' => 'Creating New Lead',
'LBL_CREATING_NEW_Accounts' => 'Creating New Account',
'LBL_CREATING_NEW_Potentials' => 'Creating New Potential',
'LBL_CREATING_NEW_Quotes' => 'Creating New Quote',
'LBL_CREATING_NEW_SalesOrder' => 'Creating New Sales Order',
'LBL_CREATING_NEW_Invoice' => 'Creating New Invoice',
'LBL_CREATING_NEW_Products' => 'Creating New Product',
'LBL_CREATING_NEW_PriceBooks' => 'Creating New Pricebook',
'LBL_CREATING_NEW_HelpDesk' => 'Creating New Ticket',
'LBL_CREATING_NEW_Faq' => 'Creating New FAQ',
'LBL_CREATING_NEW_Vendors' => 'Creating New Vendor',
'LBL_CREATING_NEW_PurchaseOrder' => 'Creating New Purchase Order',
'LBL_SEND_EMAIL_PDF' => 'Send Email With PDF',
'LBL_UPDATE' => 'Update',
//Added for incoming mail server settings form js validation
'ERR_INVALID_PAGE_COUNT' => "Invalid Page count",
'LBL_CAL_LIMIT_MSG'=>'Sorry, Year must be between 1970 and 2037',

//added for fix i18n issue #4038 when importing contacts
'Mobile' => 'Mobile',
'Home Phone' => 'Home Phone',
'Other Phone' => 'Other Phone',
'Fax' => 'Fax',
'Department' => 'Department',
'Birthdate' => 'Birthdate',
'Reports To' => 'Reports To',
'Assistant' => 'Assistant',
'Assistant Phone' => 'Assistant Phone',
'Do Not Call' => 'Do Not Call',
'Email Opt Out' => 'Email Opt Out',
'Reference' => 'Reference',
'Notify Owner' => 'Notify Owner',
'Portal User' => 'Portal User',
'Support Start Date' => 'Support Start Date',
'Support End Date' => 'Support End Date',
'Mailing Street' => 'Mailing Street',
'Other Street' => 'Other Street',
'Mailing City' => 'Mailing City',
'Other City' => 'Other City',
'Mailing State' => 'Mailing State',
'Other State' => 'Other State',
'Mailing Zip' => 'Mailing Zip',
'Other Zip' => 'Other Zip',
'Mailing Country' => 'Mailing Country',
'Other Country' => 'Other Country',
'Mailing Po Box' => 'Mailing Po Box',
'Other Po Box' => 'Other Po Box',
'Contact Image' => 'Contact Image',

//Export Records STARTS--->
'LBL_EXPORT_TYPE_1'=>'Export Type1:',
'LBL_EXPORT_TYPE_2'=>'Export Type2:',
'LBL_SEARCH_CRITERIA_RECORDS'=>'Export Search Criteria Records',
'LBL_EXPORT_RECORDS'=>'Export Records Types',
'LBL_WITH_SEARCH'=>'Export with search records',
'LBL_WITHOUT_SEARCH'=>'Export without search records',
'LBL_ALL_DATA'=>'Export all data',
'LBL_DATA_IN_CURRENT_PAGE'=>'Export data in current page',
'LBL_ONLY_SELECTED_RECORDS'=>'Export selected records',
'LBL_YES'=>'Yes',
'LBL_NO'=>'No',
'Planned'=>'Planned',
'Held'=>'Held',
'Not Held'=>'Not Held',
'Call'=>'Call',
'Meeting'=>'Meeting',
'Task'=>'Task',
'Completed'=>'Completed',
'Deferred'=>'Deferred',
'Not Started'=>'Not Started',
'In Progress'=>'In Progress',
'Pending Input'=>'Pending Input',
//Export Records <-----ENDS

'Trouble Tickets'=>'Trouble Tickets',
'LBL_NOT_ACCESSIBLE'=>'Not Accessible',

//Added for Existing Picklist Strings for both Lead module (convert div) and for potential module.

'Prospecting'=>'Prospecting',
'Qualification'=>'Qualification',
'Needs Analysis'=>'Needs Analysis',
'Value Proposition'=>'Value Proposition',
'Id. Decision Makers'=>'Id. Decision Makers',
'Perception Analysis'=>'Perception Analysis',
'Proposal/Price Quote'=>'Proposal/Price Quote',
'Negotiation/Review'=>'Negotiation/Review',
'Closed Won'=>'Closed Won',
'Closed Lost'=>'Closed Lost',
'NOTE'=>'NOTE',
//Added for Migration Alert
'before_migration'=>'before starting migration',
'Set_the_value_of'=>'Set the value of',
'as'=>'as',
'ie'=>'ie.,',
'add_at_end_of_file'=>'Please add the following lines at the end of the file config.inc.php',
// Added for Error message on Send Email failure
'LBL_MAIL_SEND_STATUS' => 'Mail Send Status:',
'LBL_MAIL_NOT_SENT_TO_USER' => 'Mail Could not be sent to user',
'LBL_PLS_CHECK_EMAIL_N_SERVER' => 'Please check the user emailid/Server settings',
'PLEASE_FILL_QUANTITY' => 'Please fill in the quantity',
'LBL_SOLUTION'=>'SOLUTION',
'LBL_COMMENTS'=>'COMMENTS',
'RELATED'=>'Related',
'SHOW_ALL'=>'Show All',
'RELATED_PARENT'=>'Related to Parent Module',
//Added for select parent role button in picklist
'LBL_SELECT_PARENTROLE' => 'Select the parent role',
//Added for migration check
'LBL_MIGRATION_CHECK'=>'Versions in database and file are same. You cannot do the migration. Please check the db and then do necessary steps.',
//Added for ticket #4595
'LBL_RECORD_NOT_FOUND'=>'Record you are trying to access is not found',
//Added for i18n issue (report 06/12/2007)
'Reorder Level' => 'Reorder Level',
'Handler' => 'Handler',
'Qty In Demand' => 'Qty In Demand',
'Annual Revenue' => 'Annual Revenue',
'No Of Employees' => 'No Of Employees',
'Employees' =>'Employees',
'Probability' => 'Probability',
'Sales Commission' =>'Sales Commission',
'Excise Duty' => 'Excise Duty',
'Budget Cost' => 'Budget Cost',
'Actual Cost' => 'Actual Cost',
'Expected Revenue' => 'Expected Revenue',
'Expected Sales Count' => 'Expected Sales Count',
'Actual Sales Count' => 'Actual Sales Count',
'Expected Response Count' => 'Expected Response Count',
'Actual Response Count' => 'Actual Response Count',
'TargetSize' => 'TargetSize',
'Expected ROI' => 'Expected ROI',
'Num Sent' => 'Num Sent',
'Actual ROI' => 'Actual ROI',
'Ascending' => 'Ascending',
'Descending' => 'Descending',
//Added for Notification
'Dear_Admin_tasks_not_been_completed' => 'Dear Admin,<br><br> Please note that there are certain tasks in the system which have not been completed even after 24hours of their existence<br>',
'Task_sign'=>'Thank You<br>HelpDesk Team<br>',
//Added for PDF notification
'LBL_PDF'=>'PDF Cannot be generated as the width exceeds the maximum limit, Kindly ',
//Added for pdf internalization in 5.0.4
'Thank You'=>'Thank You',
'For Your Business'=>'For Your Business',
'Subtotal'=>'Subtotal',
'Tax'=>'Tax',
'Adjustment'=>'Adjustment',
'Total'=>'Total',
'Description'=>'Description',
'Terms & Conditions'=>'Terms & Conditions',
'Instructions'=>'Instructions',
'Total Due'=>'Total Due',
'Detach_Info'=>'Detach on above line and send a check, money order or cashiers check in the provided envelope',
'Billing Address'=>'Billing Address',
'Order Number'=>'Order Number',
'Contact Name'=>'Contact Name',
'Vendor Name'=>'Vendor Name',
'Due Date'=>'Due Date',
'Issue Date'=>'Issue Date',
'Shipping Address'=>'Shipping Address',
'Page'=>'Page',
'Tracking No.'=>'Tracking No.',
'Req. No.'=>'Req. No.',
'Customer Name'=>'Customer Name',
'SO Number'=>'SO Number',
'Account Number'=>'Account Number',
'Valid Till'=>'Valid Till',
'Quote Number'=>'Quote Number',
'Invoice Number'=>'Invoice Number',
'Product Code'=>'Product Code',
'Qty'=>'Qty',
'Price'=>'Price',
'Discount'=>'Discount',
'LBL_ADD_BUTTON' => 'Add',

// Added after 5.0.4 GA

//Added to Fix i18N issue in Email Template
'LBL_GENERAL_FIELDS'=>'General Fields', 
//For Users fields
'HomePhone'=>'HomePhone',
'Signature'=>'Signature',
'Street'=>'Street',
'State'=>'State',
'Country'=>'Country',
'PostalCode'=>'PostalCode',
//For General fields
'Current Date'=>'Current Date',
'Current Time'=>'Current Time',

//Added for Role based Custom filters
'LBL_PUBLIC'=>'Public',
'LBL_PENDING'=>'Pending',
'LBL_OTHERS'=>'Others',

//For Configuring/Using PurchaseOrder number
'PO Number'=>'PO Number',
'MSG_AUTO_GEN_ON_SAVE'=>'AUTO GEN ON SAVE',

//For Duplicate merging feature
'LBL_MERGE' => 'Merge',
'LBL_MERGE_BUTTON_TITLE' => 'Merge',
'LBL_SAVE_MERGE_BUTTON_TITLE' => 'Find Duplicates',
'LBL_SELECT_MERGECRITERIA_HEADER' => 'Merging Criteria Selection',
'LBL_SELECT_AS_PARENT' => '(select as primary record)',
'LBL_SELECT_MERGECRITERIA_TEXT' => 'Select the match fields to find duplicate records',
'LBL_MERGE_SHOULDHAVE_INFO' => 'Select at least one field for merge criteria',
'LBL_FIND_DUPLICATES'=>'Find Duplicates',
'LBL_NO_RECORD'=>'No Records',
'LBL_NO_DUPLICATE' => 'No Duplicate Records',
'LBL_LAST_IMPORTED' => 'Last Imported',
'LBL_NOW_IMPORTED'=>'Imported Now',
'LBL_EXISTING'=> 'Existing',
'LBL_TABLE_CREATED'=>'Table Created Successfully',
'LBL_AVAILABLE_FIELDS'=>'Available Fields',
'LBL_SELECTED_FIELDS'=>' Fields to be matched on',
'LBL_MERGE_SELECT'=>'SelectRecords (max: 3)',
'DuplicatesHandling' => 'DuplicatesHandling',
'LBL_DESC_FOR_MERGE_FIELDS' => 'The primary record will be retained after the merge. You can select the column to retain the values. The other record will be deleted but the related information will be merged.',
'LBL_DUPLICATE_MERGING' => 'Duplicate Merging',
'LBL_SELECT_TO_ENABLE_MERGING' => 'Select this option to enable and set duplicate merging criteria',

// Local Backup Feature
'LBL_BACKEDUPSUCCESSFULLY_TO_FILE' => 'Backed Up Successfully To File',//BACKUP
'APP.LBL_NOW'=>'Now',//BACKUP
'LBL_NOW'=>'Now',//BACKUP

// Multi-Currency Customization
'LBL_MORE_CURRENCIES'=>'more currencies',
'LBL_BASE_CURRENCY'=>'Base Currency',
'LBL_CURRENCY'=>'Currency',
'LBL_PRICE'=>'Price',
'LBL_CONVERSION_RATE'=>'Conversion rate',
'LBL_RESET_PRICE'=>'Reset Price',
'LBL_RESET'=>'Reset',
'LBL_UNIT_PRICE_NOT_PERMITTED'=>'Access to Unit Price is Denied. So cannot select products.',

// Documents module
'SINGLE_Documents' => 'Document',
'LBL_NEW_NOTE' => 'New Document',
'Documents' => 'Documents',
'Document' => 'Document',
'LBL_NOTE' => 'Document',
'LBL_CREATING_NEW_Documents' => 'Creating New Document',
'LBL_PLATFORM_INDEPENDENT'=>'Platform Independent',
'Attachments' => 'Documents', //added for list header label in related lists
'LBL_HIDE'=>'Hide',

// Layout Editor and Ease navigation between records in Detail view
'LNK_LIST_NEXT' => 'Next',
'LNK_LIST_PREVIOUS' => 'Previous',
'LBL_JUMP_BTN'=> 'JUMP',

'LBL_ASSIGN_BUTTON_LABEL'=>'Assign Fields',

// Mass Edit Feature
'LBL_MASS_EDIT'=>'Mass Edit',
'LBL_MASSEDIT_FORM_HEADER'=>'Mass Edit - Records Fields',

// Product Bundles
'Product Bundles'=>'Product Bundles',

// vtlib customization: Language strings
'VTLIB_MOD_NOT_ACTIVE' => ' module is not active!',
// END

// vtiger News & Feedback
'LBL_VTIGER_NEWS'=>'vtiger News',
'LBL_FEEDBACK'=>'Feedback',
// END

//added for asterisk integration
'CallHistory'=>'Call History',
'PBXManager'=>'PBX Manager',
'LBL_OUTGOING_CALL_MESSAGE'=>'Pick up the extensions receiver to dial the number',
'LBL_OUTGOING_CALL'=>'Outgoing Call',
'LBL_OPERATION_NOT_SUPPORTED'=>'This Operation is currently not supported',
'LBL_ASTERISK_SET_ERROR'=>'Asterisk server details are not set. Set them first.',
'LBL_CREATE_LEAD'=>'Create Lead',
'LBL_CREATE_CONTACT'=>'Create Contact',
'LBL_CREATE_ACCOUNT'=>'Create Account',
'LBL_CREATE_TICKET'=>'Create Tickets',
'LBL_INCOMING_CALL'=>'Incoming Call',
'LBL_CALLER_INFORMATION'=>'Caller Information',
'LBL_CALLER_NUMBER'=>'Number :',
'LBL_CALLER_NAME'=>'Name :',
'LBL_INFORMATION_VTIGER'=>'Information from Vtiger',

//asterisk integration ends

// Module Sequence Numbering
'LBL_DUPLICATE' => 'Duplicate',
'LBL_CLICK' => 'Click',
'LBL_TO_CONFIGURE' => 'to Configure the',

// For Privacy Policy
'LNK_PRIVACY_POLICY'=>'Privacy Policy',
'LBL_MOVE_BLOCK_FIELD' => 'Move Fields',
 
//added for find duplicate
'LBL_DUPLICATE_DATA_IN'=>'Duplicate ',
'LBL_DELETE'=>'Delete',
'LBL_MERGE_SELECT'=>'Merge Select',
'LBL_MERGE_DATA_IN'=>'Merge Records In',
'LBL_MERGE'=>'Merge',
'LBL_ACTION'=>'Action',
'LBL_FIELDLISTS'=> 'List Of Fields',
'LBL_RECORD'=>'Record #',
'LBL_DUP_PERMISSION' => 'You are not permitted to delete ',
'recordid' => 'recordid',
'Entity Type' => 'Entity Type',

// gmailbookmarklet customization
'LBL_GMAIL'=>'Gmail',
'LBL_BOOKMARKLET'=>'Bookmarklet',
// END

//ADDED for REPORTS CUSTOMIZING
'PRIVATE_FILTER'=>'Private',
'SHARE_FILTER'=>'Share',
'PUBLIC_FILTER'=>'Public',

// Account Hierarchy
'LBL_ACCOUNT_HIERARCHY' => 'Account Hierarchy', 

//Prod Bundles
'LBL_NO_SUB_PRODUCTS'=>'Not a Bundle',

//Custom Fields support for Calendar
'LBL_ACTIVITY_TYPE'=>'Activity Type',

// Services model
'LBL_ADD_SERVICE'=>'Add Service',
'LBL_ITEM_DETAILS'=>'Item Details',
'LBL_ITEM_NAME'=>'Item Name',
'LBL_SETTINGS'=>'Settings',
'LAYOUT_EDITOR'=>'Layout Editor',
'CUSTOMFIELD_MAPPING'=>'CustomField Mapping',
'ADD_PORTAL'=>'Add To Portal',
'LBL_FILE_INTEGRITY_CHECK'=>'Check integrity of this file',

//To handle plurals of module names
'Todos' => 'Todos',

// For Popup reminder
'LBL_POSTPONE'=>'Postpone',

// Unified Search extended support
'LBL_SELECT_MODULES_FOR_SEARCH' => 'Select modules to search in',
'LBL_SELECT_ALL' => 'Select All', 
'LBL_UNSELECT_ALL' => 'UnSelect All',
'LBL_FIELD_FOR_COMPARISION' => 'Field for Comparision',
'LBL_DONE' => ' Done ',

'LBL_NO_MODULES_TO_SELECT' => 'Operation Denied. No Modules to act on.',

'CANNOT_CONVERT' => 'Cannot be Converted',

// For note link on the detailview
'LBL_ADD_NOTE'=>'Add Note',

// For Layout Editor 
'LBL_UNHIDE_FIELDS'=>'Unhide Fields',

// For Mass Edit
'LBL_SELECT_FIELDS_TO_UDPATE_WITH_NEW_VALUE'=>'Select fields to be updated and provide the new value.',

'LBL_LOADING'=>'Loading...',
);

$app_list_strings = array (
  'moduleList' => 
  array (
    'Home' => 'Home',
    'Dashboard' => 'Dashboard',
    'Leads' => 'Leads',
    'Contacts' => 'Contacts',
    'Accounts' => 'Accounts',
    'Potentials' => 'Potentials',
    'Campaigns' => 'Campaigns',
    'Emails' => 'Emails',
    'Activities' => 'Activities',
    'Products' => 'Products',
    'HelpDesk' => 'Trouble Tickets',
    'Faq' => 'FAQ',
    'Calendar' => 'Calendar',
    'Quotes' => 'Quotes',
    'PurchaseOrder' => 'PurchaseOrder',
    'Invoice' => 'Invoice',
    'Rss' => 'RSS',
    'Reports' => 'Reports',
    'Vendors' => 'Vendors',
    'PriceBooks' => 'PriceBooks',
    'SalesOrder' => 'SalesOrder',
    'Portal' => 'My Sites',
	
	// Added after 5.0.4 GA
    'Documents' => 'Documents',
  ),
  'opportunity_relationship_type_default_key' => 'Primary Decision Maker',
  'opportunity_relationship_type_dom' => 
  array (
    '' => '',
    'Primary Decision Maker' => 'Primary Decision Maker',
    'Business Decision Maker' => 'Business Decision Maker',
    'Business Evaluator' => 'Business Evaluator',
    'Technical Decision Maker' => 'Technical Decision Maker',
    'Technical Evaluator' => 'Technical Evaluator',
    'Executive Sponsor' => 'Executive Sponsor',
    'Influencer' => 'Influencer',
    'Other' => 'Other',
  ),
  'case_relationship_type_default_key' => 'Primary Contact',
  'case_relationship_type_dom' => 
  array (
    '' => '',
    'Primary Contact' => 'Primary Contact',
    'Alternate Contact' => 'Alternate Contact',
  ),
  'task_priority_dom' => 
  array (
    'High' => 'High',
    'Medium' => 'Medium',
    'Low' => 'Low',
  ),
  'task_status_dom' => 
  array (
    'Planned' => 'Planned',
    'Completed' => 'Completed',
    'Deferred' => 'Deferred',
  ),
  'meeting_status_dom' => 
  array (
    'Planned' => 'Planned',
    'Held' => 'Held',
    'Not Held' => 'Not Held',
  ),
  'call_status_dom' => 
  array (
    'Planned' => 'Planned',
    'Held' => 'Held',
    'Not Held' => 'Not Held',
  ),
  'case_status_default_key' => 'New',
  'case_status_dom' => 
  array (
    'New' => 'New',
    'Assigned' => 'Assigned',
    'Closed' => 'Closed',
    'Pending Input' => 'Pending Input',
    'Rejected' => 'Rejected',
  ),
  'user_status_dom' => 
  array (
    'Active' => 'Active',
    'Inactive' => 'Inactive',
  ),
  'record_type_default_key' => 'Accounts',
  'record_type_display' => 
  array (
    'Accounts' => 'Account',
    'Leads' => 'Lead',
    'Opportunities' => 'Opportunity',
  ),

); 

// Translation for currency names
$app_currency_strings = array(
	'Albania, Leke' 		=> 'Albania, Leke',
	'Argentina, Pesos' 		=> 'Argentina, Pesos',
	'Aruba, Guilders' 		=> 'Aruba, Guilders',
	'Australia, Dollars' 	=> 'Australia, Dollars',
	'Azerbaijan, New Manats'=> 'Azerbaijan, New Manats',
	'Bahamas, Dollars' 		=> 'Bahamas, Dollars',
	'Bahrain, Dinar' 		=> 'Bahrain, Dinar',
	'Barbados, Dollars' 	=> 'Barbados, Dollars',
	'Belarus, Rubles' 		=> 'Belarus, Rubles',
	'Belize, Dollars' 		=> 'Belize, Dollars',
	'Bermuda, Dollars' 		=> 'Bermuda, Dollars',
	'Bolivia, Bolivianos' 	=> 'Bolivia, Bolivianos',
	'Convertible Marka'		=> 'Convertible Marka',
	'Botswana, Pulas' 		=> 'Botswana, Pulas',
	'Bulgaria, Leva' 		=> 'Bulgaria, Leva',
	'Brazil, Reais' 		=> 'Brazil, Reais',
	'Great Britain Pounds' 	=> 'Great Britain Pounds',
	'Brunei Darussalam, Dollars' => 'Brunei Darussalam, Dollars',
	'Canada, Dollars' 		=> 'Canada, Dollars',
	'Cayman Islands, Dollars' => 'Cayman Islands, Dollars',
	'Chile, Pesos' 			=> 'Chile, Pesos',
	'Colombia, Pesos' 		=> 'Colombia, Pesos',
	'Costa Rica, Colón' 	=> 'Costa Rica, Colón',
	'Croatia, Kuna' 		=> 'Croatia, Kuna',
	'Cuba, Pesos' 			=> 'Cuba, Pesos',
	'Czech Republic, Koruny' => 'Czech Republic, Koruny',
	'Denmark, Kroner' 		=> 'Denmark, Kroner',
	'Dominican Republic, Pesos' => 'Dominican Republic, Pesos',
	'East Caribbean, Dollars' => 'East Caribbean, Dollars',
	'Egypt, Pounds' 		=> 'Egypt, Pounds',
	'El Salvador, Colones' 	=> 'El Salvador, Colones',
	'England, Pounds' 		=> 'England, Pounds',
	'Estonia, Krooni' 		=> 'Estonia, Krooni',
	'Euro' 					=> 'Euro',
	'Falkland Islands, Pounds' => 'Falkland Islands, Pounds',
	'Fiji, Dollars' => 'Fiji, Dollars',
	'Ghana, Cedis' 	=> 'Ghana, Cedis',
	'Gibraltar, Pounds' 	=> 'Gibraltar, Pounds',
	'Guatemala, Quetzales' 	=> 'Guatemala, Quetzales',
	'Guernsey, Pounds' 		=> 'Guernsey, Pounds',
	'Guyana, Dollars' 		=> 'Guyana, Dollars',
	'Honduras, Lempiras' 	=> 'Honduras, Lempiras',
	'LvHong Kong, Dollars ' => 'LvHong Kong, Dollars ',
	'Hungary, Forint' 		=> 'Hungary, Forint',
	'Iceland, Krona' 		=> 'Iceland, Krona',
	'India, Rupees' 		=> 'India, Rupees',
	'Indonesia, Rupiahs' 	=> 'Indonesia, Rupiahs',
	'Iran, Rials' 			=> 'Iran, Rials',
	'Isle of Man, Pounds' 	=> 'Isle of Man, Pounds',
	'Israel, New Shekels' 	=> 'Israel, New Shekels',
	'Jamaica, Dollars' 		=> 'Jamaica, Dollars',
	'Japan, Yen' 			=> 'Japan, Yen',
	'Jersey, Pounds' 		=> 'Jersey, Pounds',
	'Kazakhstan, Tenge' 	=> 'Kazakhstan, Tenge',
	'Korea (North), Won' 	=> 'Korea (North), Won',
	'Korea (South), Won' 	=> 'Korea (South), Won',
	'Kyrgyzstan, Soms' 		=> 'Kyrgyzstan, Soms',
	'Laos, Kips' 			=> 'Laos, Kips',
	'Latvia, Lati' 			=> 'Latvia, Lati',
	'Lebanon, Pounds' 		=> 'Lebanon, Pounds',
	'Liberia, Dollars' 		=> 'Liberia, Dollars',
	'Switzerland Francs' 	=> 'Switzerland Francs',
	'Lithuania, Litai' 		=> 'Lithuania, Litai',
	'Macedonia, Denars' 	=> 'Macedonia, Denars',
	'Malaysia, Ringgits' 	=> 'Malaysia, Ringgits',
	'Mauritius, Rupees' 	=> 'Mauritius, Rupees',
	'Mexico, Pesos' 		=> 'Mexico, Pesos',
	'Mongolia, Tugriks' 	=> 'Mongolia, Tugriks',
	'Mozambique, Meticais' 	=> 'Mozambique, Meticais',
	'Namibia, Dollars' 		=> 'Namibia, Dollars',
	'Nepal, Rupees' 		=> 'Nepal, Rupees',
	'Netherlands Antilles, Guilders' => 'Netherlands Antilles, Guilders',
	'New Zealand, Dollars' 	=> 'New Zealand, Dollars',
	'Nicaragua, Cordobas' 	=> 'Nicaragua, Cordobas',
	'Nigeria, Nairas' 		=> 'Nigeria, Nairas',
	'North Korea, Won' 		=> 'North Korea, Won',
	'Norway, Krone' 		=> 'Norway, Krone',
	'Oman, Rials' 			=> 'Oman, Rials',
	'Pakistan, Rupees' 		=> 'Pakistan, Rupees',
	'Panama, Balboa' 		=> 'Panama, Balboa',
	'Paraguay, Guarani' 	=> 'Paraguay, Guarani',
	'Peru, Nuevos Soles' 	=> 'Peru, Nuevos Soles',
	'Philippines, Pesos' 	=> 'Philippines, Pesos',
	'Poland, Zlotych' 		=> 'Poland, Zlotych',
	'Romania, New Lei' 		=> 'Romania, New Lei',
	'Russia, Rubles'		=> 'Russia, Rubles',
	'Saint Helena, Pounds' => 'Saint Helena, Pounds',
	'Saudi Arabia, Riyals' => 'Saudi Arabia, Riyals',
	'Serbia, Dinars' 		=> 'Serbia, Dinars',
	'Seychelles, Rupees' 	=> 'Seychelles, Rupees',
	'Singapore, Dollars' 	=> 'Singapore, Dollars',
	'Solomon Islands, Dollars' => 'Solomon Islands, Dollars',
	'Somalia, Shillings' => 'Somalia, Shillings',
	'South Africa, Rand' => 'South Africa, Rand',
	'South Korea, Won' 	=> 'South Korea, Won',
	'Sri Lanka, Rupees' => 'Sri Lanka, Rupees',
	'Sweden, Kronor' 	=> 'Sweden, Kronor',
	'Switzerland, Francs' => 'Switzerland, Francs',
	'Suriname, Dollars' 	=> 'Suriname, Dollars',
	'Syria, Pounds' 		=> 'Syria, Pounds',
	'Taiwan, New Dollars' 	=> 'Taiwan, New Dollars',
	'Thailand, Baht' 		=> 'Thailand, Baht',
	'Trinidad and Tobago, Dollars' => 'Trinidad and Tobago, Dollars',
	'Turkey, New Lira' 		=> 'Turkey, New Lira',
	'Turkey, Liras' 		=> 'Turkey, Liras',
	'Tuvalu, Dollars' 		=> 'Tuvalu, Dollars',
	'Ukraine, Hryvnia' 		=> 'Ukraine, Hryvnia',
	'United Kingdom, Pounds' => 'United Kingdom, Pounds',
	'USA, Dollars' 			=> 'USA, Dollars',
	'Uruguay, Pesos' 		=> 'Uruguay, Pesos',
	'Uzbekistan, Sums' 		=> 'Uzbekistan, Sums',
	'Venezuela, Bolivares Fuertes' => 'Venezuela, Bolivares Fuertes',
	'Vietnam, Dong' 		=> 'Vietnam, Dong',
	'Zimbabwe Dollars' 		=> 'Zimbabwe Dollars',
	'China, Yuan Renminbi' 	=> 'China, Yuan Renminbi',
	'Afghanistan, Afghanis' => 'Afghanistan, Afghanis',
	'Cambodia, Riels' 		=> 'Cambodia, Riels',
);
?>